<?php

namespace Modules\Cotacao\Modules\Pedido\Services;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Util\SupUtilities;
use \Teknisa\Libs\Util\Utilities as LibUtilities;
use Teknisa\Libs\Util\XLS\FileLoader;
use Teknisa\Libs\Util\XLS\FileReader;
use Teknisa\Libs\Util\XLS\Table;
use PHPExcel_Cell;
use PHPExcel_Worksheet;


class Sup09600IImportacaodeRFPService
{
    protected $entityManager;
    protected $environment;
    protected $connection;
    protected $utilities;
    protected $newCode;
    protected $errors = array();
    public function __construct($entityManager, $environment, $connection, SupUtilities $supUtilities, LibUtilities $utilities, $newCode)
    {
        $this->entityManager = $entityManager;
        $this->environment   = $environment;
        $this->connection    = $connection;
        $this->supUtilities  = $supUtilities;
        $this->utilities = $utilities;
        $this->newCode    = $newCode;
    }
    
    /********************
     *   TRANSACTIONS   *
     ********************/
    
    public function beginTransaction()
    {
        $this->entityManager->beginTransaction();
    }
    
    public function commitTransaction()
    {
        $this->entityManager->commit();
    }
    
    public function rollbackTransaction()
    {
        $this->entityManager->rollback();
    }
    
    public function callProcedureVerificaImport(array $lista, array $para){
        try{
            $procedure = new StoredProcedure($this->connection, 'TEKNISA_RFP.CHECK_IMPORT');
            $procedure->addParam(new Param('P_NRRFPMAIN', Param::PARAM_INPUT, $lista['P_NRRFPMAIN'], Param::PARAM_TYPE_STR));
            $procedure->execute();
        }catch(\Exception $e){
            return $e;
        }
    }
    
    public function setError($rowNum, $columnName, $value, $message, $secondValue = null) {
        array_push(
            $this->errors, 
            array(
                "ROWNUM" => $rowNum,
                "COLUMN" => $columnName,
                "VALUE" => $value,
                "ERROR_CODE" => $message,
                "SECOND_VALUE" => $secondValue
            )
        );
    }
   
    public function limpaCPF_CNPJ($valor){
 $valor = trim($valor);
 $valor = str_replace(".", "", $valor);
 $valor = str_replace(",", "", $valor);
 $valor = str_replace("-", "", $valor);
 $valor = str_replace("/", "", $valor);
 return $valor;
}
   
    public function readXlsHeader($row, $response){
            $file = $row['FILE'];
            $sheetsToLoad = array('Sheasdasdsadet1', 'Sheet1', 'Planilha1');
            $xlsFile = FileLoader::loadFromBase64($file['content'], $file['name']);
            if(!$xlsFile){
                throw new \Exception(self::IMPORT_LOAD_FILE_ERROR);
            }
            $worksheet = $xlsFile->getActiveSheet();
             $cellC1 = $worksheet->getCell('C1');//Nome Arquivo
            /*$cellO1 = $worksheet->getCell('O1');//Dados Arquivo
            //
            $cellE2 = $worksheet->getCell('E2');//Regiao*/
            $cellE3 = $worksheet->getCell('E3');//Regiao 1
            $cellE4 = $worksheet->getCell('E4');//Regiao 2
            $cellE5 = $worksheet->getCell('E5');//Regiao 3
            $cellE6 = $worksheet->getCell('E6');//Regiao 4
            $cellF3 = $worksheet->getCell('F3');//Regiao 5
            $cellF4 = $worksheet->getCell('F4');//Regiao 6
            $cellF5 = $worksheet->getCell('F5');//Regiao 7
            $cellF6 = $worksheet->getCell('F6');//Regiao 8
            //
            //$cellC2 = $worksheet->getCell('C2');//Validade*/ 
            $cellD3 = $worksheet->getCell('D3');//Validade Inicial
            $cellD4 = $worksheet->getCell('D4');//Validade Final
            /*$cellG2 = $worksheet->getCell('G2');//UF atendida
            $cellH2 = $worksheet->getCell('H2');//UF 1
            $cellH3 = $worksheet->getCell('H3');//UF 2
            $cellH4 = $worksheet->getCell('H4');//UF 3
            $cellH5 = $worksheet->getCell('H5');//UF 4
            $cellH6 = $worksheet->getCell('H6');//UF 5
            $cellI2 = $worksheet->getCell('I2');//UF 6
            $cellI3 = $worksheet->getCell('I3');//UF 7
            $cellI4 = $worksheet->getCell('I4');//UF 8
            $cellI5 = $worksheet->getCell('I5');//UF 9
            $cellI6 = $worksheet->getCell('I6');//UF 10
            //
            $cellJ2 = $worksheet->getCell('J2');//Exceção Regiao
            $cellJ3 = $worksheet->getCell('J3');//Exceção Regiao 1
            $cellJ4 = $worksheet->getCell('J4');//Exceção Regiao 2
            $cellJ5 = $worksheet->getCell('J5');//Exceção Regiao 3
            $cellJ6 = $worksheet->getCell('J6');//Exceção Regiao 4
            //
            //$cellK2 = $worksheet->getCell('K2');//Responsavel*/
            $cellM2 = $worksheet->getCell('M2');//Responsavel Nome
            /*$cellK3 = $worksheet->getCell('K3');//Email Responsavel
            $cellM3 = $worksheet->getCell('M3');//Email
            //
            $cellK5 = $worksheet->getCell('K5');//Filial
            $cellM5 = $worksheet->getCell('M5');//Filial Valor
            //
            $cellK6 = $worksheet->getCell('K6');//Versao
            $cellM6 = $worksheet->getCell('M6');//Versao Valor
            //
            $cellO2 = $worksheet->getCell('O2');//Regiao 2
            $cellO3 = $worksheet->getCell('O3');//Regiao 2 1
            $cellO4 = $worksheet->getCell('O4');//Regiao 2 2
            $cellO5 = $worksheet->getCell('O5');//Regiao 2 3
            $cellO6 = $worksheet->getCell('O6');//Regiao 2 4
            $cellP3 = $worksheet->getCell('P3');//Regiao 2 5
            $cellP4 = $worksheet->getCell('P4');//Regiao 2 6
            $cellP5 = $worksheet->getCell('P5');//Regiao 2 7
            $cellP6 = $worksheet->getCell('P6');//Regiao 2 8
            $cellQ3 = $worksheet->getCell('Q3');//Regiao 2 9
            $cellQ4 = $worksheet->getCell('Q4');//Regiao 2 10
            $cellQ5 = $worksheet->getCell('Q5');//Regiao 2 11
            $cellQ6 = $worksheet->getCell('Q6');//Regiao 2 12
            //
            //$cellA6 = $worksheet->getCell('A6');//Codigo comprador*/
            $cellB6 = $worksheet->getCell('B6');//Codigo comprador valor
            /*$cellA7 = $worksheet->getCell('A7');//Nome comprador
            $cellB7 = $worksheet->getCell('B7');//Nome comprador valor
            //
            $cellA8 = $worksheet->getCell('A8');//Nome fornecedor
            $cellB8 = $worksheet->getCell('B8');//Nome fornecedor valor
            //
            $cellC6 = $worksheet->getCell('C6');//DATA
            $cellD6 = $worksheet->getCell('D6');//DATA valor
            //*/
            $cellD8 = $worksheet->getCell('D8');//CNPJ 1 valor
            $cellG8 = $worksheet->getCell('G8');//CNPJ 2 valor
            $cellJ8 = $worksheet->getCell('J8');//CNPJ 3 valor
            $cellM8 = $worksheet->getCell('M8');//CNPJ 4 valor
            $cellP8 = $worksheet->getCell('P8');//CNPJ 5 valor
            $cellD9 = $worksheet->getCell('D9');//CNPJ 6 valor
            $cellG9 = $worksheet->getCell('G9');//CNPJ 7 valor
            $cellJ9 = $worksheet->getCell('J9');//CNPJ 8 valor
            $cellM9 = $worksheet->getCell('M9');//CNPJ 9 valor
            $cellP9 = $worksheet->getCell('P9');//CNPJ 10 valor
            //
            $inicial =  gmdate('d/m/Y', ((int)$cellD3->getValue() - 25569) * 86400);
            $final =  gmdate('d/m/Y', ((int)$cellD4->getValue() - 25569) * 86400);
            $params = [
            "COMPRADOR" => $cellB6->getValue() !== NULL ? str_pad($cellB6->getValue(), 12, '0', STR_PAD_LEFT) : NULL,
            "DTVALIDADEINICIAL" => $cellD3->getValue() !== NULL ? $inicial : NULL,
            "DTVALIDADEFINAL" => $cellD4->getValue() !== NULL ? $final : NULL,
            "STATUS" => 'PENDENTE',
            "DTIMPORTACAO" => date("d/m/Y"),
            "RESPONSAVEL" => $cellM2->getValue() !== NULL ? $cellM2->getValue() : NULL,
            "DSARQUIVO" => $cellC1->getValue() !== NULL ? $cellC1->getValue() : NULL,
            "CDOPERLOGADO" => $this->environment->getCdoperador(),
            "CDFILIAL" => $this->environment->getCdFilial()
            ];
            $regions = [
            "0" => $cellE3->getValue() !== NULL ? $cellE3 : NULL,
            "1" => $cellE4->getValue() !== NULL ? $cellE4 : NULL,
            "2" => $cellE5->getValue() !== NULL ? $cellE5 : NULL,
            "3" => $cellE6->getValue() !== NULL ? $cellE6 : NULL,
            "4" => $cellF3->getValue() !== NULL ? $cellF3 : NULL,
            "5" => $cellF4->getValue() !== NULL ? $cellF4 : NULL,
            "6" => $cellF5->getValue() !== NULL ? $cellF5 : NULL,
            "7" => $cellF6->getValue() !== NULL ? $cellF6 : NULL
            ];
            $cnpj = [
            "0" => $cellD8->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellD8->getValue()) : NULL,
            "1" => $cellG8->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellG8->getValue()) : NULL,
            "2" => $cellJ8->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellJ8->getValue()) : NULL,
            "3" => $cellM8->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellM8->getValue()) : NULL,
            "4" => $cellP8->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellP8->getValue()) : NULL,
            "5" => $cellD9->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellD9->getValue()) : NULL,
            "6" => $cellG9->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellG9->getValue()) : NULL,
            "7" => $cellJ9->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellJ9->getValue()) : NULL,
            "8" => $cellM9->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellM9->getValue()) : NULL,
            "9" => $cellP9->getValue() !== NULL ? $this->limpaCPF_CNPJ($cellP9->getValue()) : NULL
            ];
            $regionsparams = array_filter($regions);
            $cnpjparams = array_filter($cnpj);
            $lenregions = count($regionsparams);
            $lencnpj = count($cnpjparams);
            if(!in_array(NULL, $params, true)){
                $searchRFPMAIN = [
            "COMPRADOR" => str_pad($cellB6->getValue(), 12, '0', STR_PAD_LEFT),
            "DTVALIDADEINICIAL" => $inicial,
            "DTVALIDADEFINAL" => $final,
            "RESPONSAVEL" => $cellM2->getValue(),
            "DSARQUIVO" => $cellC1->getValue()
            ];
                $searchNR = $this->searchNRRFPMAIN($searchRFPMAIN);
                $searchStatus = $this->searchSTATUS($searchRFPMAIN);
                if(empty($searchNR)) {
                     $this->insertRFPMAIN($params);
                     $searchNRparam = $this->searchNRRFPMAIN($searchRFPMAIN);
                        if(!empty(array_filter($regionsparams))){
                            for($i = 0; $i < $lenregions; $i++){
                             $this->insertRFPREGIAO($regionsparams[$i]->getValue(),$searchNRparam); 
                            }
                        }
                        if(!empty(array_filter($cnpjparams))){
                            for($i = 0; $i < $lencnpj; $i++){
                             $this->insertRFPFORNECEDOR($cnpjparams[$i],$searchNRparam); 
                            }
                        }
                     $result = ['MESSAGE' => 'SUCCESS'];
                }
                else if($searchStatus == 'PENDENTE'){
                $result = ['MESSAGE' => 'ATUALIZAR_ALTER_IMPORT'];
                }
            }//
            else if (in_array(NULL, $params, true)){
                $key = array_keys($params, null, true);
                if($key[0] == 'DTVALIDADEFINAL')$cell='Linha: 4 Coluna: D';
                if($key[0] == 'DTVALIDADEINICIAL')$cell='Linha: 3 Coluna: D';
                if($key[0] == 'CDCOMPRADOR')$cell='Linha: 6 Coluna: B';
                if($key[0] == 'RESPONSAVEL')$cell='Linha: 2 Coluna: M';
                if($key[0] == 'DSARQUIVO')$cell='Linha: 1 Coluna: C';
                $result = ['MESSAGE' => 'VALOR_NAO_INFOR_HEAD__PARAM',
                'textContentError' => $cell];
            }
            else $result = ['MESSAGE' => 'IMPOSSIVEL_ADICIONAR'];
            return $result;
    }

    public function readXls($row){
        try {
            $file = $row['FILE'];
            
            $sheetsToLoad = array('Sheasdasdsadet1', 'Sheet1', 'Planilha1');
            $xlsFile = FileLoader::loadFromBase64($file['content'], $file['name']);
            if(!$xlsFile){
                throw new \Exception(self::IMPORT_LOAD_FILE_ERROR);
            }
            $columnNames = ["CÓDIGO", "DESCRIÇÃO", "CÓDIGO", "NOME", "PREÇO", "CÓDIGO", "NOME", "PREÇO","CÓDIGO", "NOME", "PREÇO","CÓDIGO", "NOME", "PREÇO"];
            $worksheet = $xlsFile->getActiveSheet();
            $cellC1 = $worksheet->getCell('C1');//Nome Arquivo
            $cellB6 = $worksheet->getCell('B6');//Codigo comprador valor
            $cellM2 = $worksheet->getCell('M2');//Responsavel Nome
            $cellD3 = $worksheet->getCell('D3');//Validade Inicial
            $cellD4 = $worksheet->getCell('D4');//Validade Final
            $inicial =  gmdate('d/m/Y', ((int)$cellD3->getValue() - 25569) * 86400);
            $final =  gmdate('d/m/Y', ((int)$cellD4->getValue() - 25569) * 86400);
            $searchRFPMAIN = [
            "CDCOMPRADOR" => str_pad($cellB6->getValue(), 12, '0', STR_PAD_LEFT),
            "DTVALIDADEINICIAL" => $inicial,
            "DTVALIDADEFINAL" => $final,
            "RESPONSAVEL" => $cellM2->getValue(),
            "DSARQUIVO" => $cellC1->getValue()
            ];
            $table = $this->formatXls($worksheet, $columnNames, $searchRFPMAIN);
            if(array_key_exists('ERROS', $table))$result = ['MESSAGE' => $table['ERROS'][0]['ERROR_CODE'],'textContentError' => 'Linha: '.$table['ERROS'][0]['ROWNUM'].' Coluna: '.$table['ERROS'][0]['COLUMN']];
            if(empty($table["ERROS"])) {
                $result = ['MESSAGE' => 'SUCCESS'];
            }
            return $result;
        } catch (\Exception $e){
            throw $e;
        }
    }
    
    protected static function getColumnIndex($column){
        if(gettype($column) == 'string')
            return PHPExcel_Cell::columnIndexFromString($column) - 1 ;
        else
            return $column;
    }
    
    protected static function isHeaderSizeRight($maxColumn, $columnNames){
        return ($maxColumn == count($columnNames) - 1);  
    }
    
    protected static function getColumnString($column){
        if(gettype($column) == 'integer')
            return PHPExcel_Cell::stringFromColumnIndex($column);
        else
            return $column;
    }
    
    protected static function buildColumnNameReference($worksheet, $maxColumn, $columnNames){
        $reference = array();
            for($column = 0; $column <= $maxColumn; $column++){
                $columnString = self::getColumnString($column);
                $columnName = $worksheet->getCell($columnString.'1')->getValue();
                $reference[$columnString] = mb_strtoupper($columnName, 'UTF-8');
            }
        return ($reference);
    }
    
    public function formatXls(PHPExcel_Worksheet $worksheet, $columnNames, $searchRFPMAIN){
        $nrrfp = $this->searchNRRFPMAIN($searchRFPMAIN);
        //
        $codigo = null;
        $codigomarca1 = null;$nomemarca1 = null;$precomarca1 = null;
        $codigomarca2 = null;$nomemarca2 = null;$precomarca2 = null;
        $codigomarca3 = null;$nomemarca3 = null;$precomarca3 = null;
        $codigomarca4 = null;$nomemarca4 = null;$precomarca4 = null;
        $codigomarca5 = null;$nomemarca5 = null;$precomarca5 = null;
        //
        $minRowIndex = 14;
        $worksheetDimensions = $worksheet->getHighestRowAndColumn();
        $maxRowIndex = $worksheetDimensions['row'];
        $maxColumnIndex = self::getColumnIndex($worksheetDimensions['column']);
        $columnsReference = self::buildColumnNameReference($worksheet, $maxColumnIndex, $columnNames);
        $tableRows = array();
        for($row = $minRowIndex; $row <= $maxRowIndex; $row++){
            $worksheetRowContent = array();
            $rowIsEmpty = true;
            for($column = 0; $column <= $maxColumnIndex; $column++){
                $columnLetterIndex = PHPExcel_Cell::stringFromColumnIndex($column);
                $columnName = $columnsReference[$columnLetterIndex];
                $cellValue = $worksheet->getCell($columnLetterIndex.$row)->getValue();
                if($cellValue !== NULL){
                    $rowIsEmpty = false;
                    $cellValue = $worksheet->getCell($columnLetterIndex.$row)->getFormattedValue();
                    if($columnLetterIndex == "A") {
                        $codigo = $cellValue;
                    } else if($columnLetterIndex == "B"){
                        $descricao = $cellValue;
                    } else if($columnLetterIndex == "C"){
                        $codigomarca1 = str_pad($cellValue->getValue(), 5, '0', STR_PAD_LEFT);
                    } else if($columnLetterIndex == "D"){
                        $nomemarca1 = $cellValue;
                    } else if($columnLetterIndex == "E"){
                        $precomarca1 = $cellValue;
                    } else if($columnLetterIndex == "F"){
                        $codigomarca2 = str_pad($cellValue->getValue(), 5, '0', STR_PAD_LEFT);
                    } else if($columnLetterIndex == "G"){
                        $nomemarca2 = $cellValue;
                    } else if($columnLetterIndex == "H"){
                        $precomarca2 = $cellValue;
                    } else if($columnLetterIndex == "I"){
                        $codigomarca3 = $str_pad($cellValue->getValue(), 5, '0', STR_PAD_LEFT);
                    } else if($columnLetterIndex == "J"){
                        $nomemarca3 = $cellValue;
                    } else if($columnLetterIndex == "K"){
                        $precomarca3 = $cellValue;
                    } else if($columnLetterIndex == "L"){
                        $codigomarca4 = str_pad($cellValue->getValue(), 5, '0', STR_PAD_LEFT);
                    } else if($columnLetterIndex == "M"){
                        $nomemarca4 = $cellValue;
                    } else if($columnLetterIndex == "N"){
                        $precomarca4 = $cellValue;
                    } else if($columnLetterIndex == "O"){
                        $codigomarca5 = str_pad($cellValue->getValue(), 5, '0', STR_PAD_LEFT);
                    } else if($columnLetterIndex == "P"){
                        $nomemarca5 = $cellValue;
                    } else if($columnLetterIndex == "Q"){
                        $precomarca5 = $cellValue;
                    }
                } else {
                    if(($columnLetterIndex == "A" || $columnLetterIndex == "C" || $columnLetterIndex == "D" || $columnLetterIndex == "E")&&($cellValue == NULL)){
                        $this->setError($row, $columnLetterIndex, $cellValue, "VALOR_NAO_INFOR");
                    }
                }
                $worksheetRowContent = array_merge($worksheetRowContent, array($columnName => $cellValue));
            }
            $p1 = substr($precomarca1, 3, -1);
            $p2 = substr($precomarca2, 3, -1);
            $p3 = substr($precomarca3, 3, -1);
            $p4 = substr($precomarca4, 3, -1);
            $p5 = substr($precomarca5, 3, -1);
            if(!$rowIsEmpty){
                $params = [
                "NRRFPMAIN" => intval($nrrfp),
                "CODPRODUTO" => $codigo,
                "CODMARCA1" => $codigomarca1,
                "NMMARCA1" => $nomemarca1,
                "VRPRECO1" => $p1,
                "CODMARCA2" => $codigomarca2,
                "NMMARCA2" => $nomemarca2,
                "VRPRECO2" => $p2,
                "CODMARCA3" => $codigomarca3,
                "NMMARCA3" => $nomemarca3,
                "VRPRECO3" => $p3,
                "CODMARCA4" => $codigomarca4,
                "NMMARCA4" => $nomemarca4,
                "VRPRECO4" => $p4,
                "CODMARCA5" => $codigomarca5,
                "NMMARCA5" => $nomemarca5,
                "VRPRECO5" => $p5
                ];
                $worksheetRow = array(
                    'index' => $row,
                    'content' => $worksheetRowContent
                );
                array_push($tableRows, $worksheetRow);
            }
             try{
              $this->insertRFPPRODMARCA($params);
              $this->callProcedureVerificaImport($nrrfp);
             } catch (\Exception $e) {
                $this->deleteRFPFORNECEDOR(intval($nrrfp));
                $this->deleteRFPREGIAO(intval($nrrfp));
                $this->deleteRFPPRODMARCA(intval($nrrfp));
                $this->deleteRFMAIN(intval($nrrfp));
                $this->deleteRFMAIN(intval($nrrfp));
               }            
        }
        $table = new Table($columnsReference, $tableRows);
        $rowsFromTable = $table->getRows();
        if($this->errors != null){
            $this->deleteRFPFORNECEDOR(intval($nrrfp));
            $this->deleteRFPREGIAO(intval($nrrfp));
            $this->deleteRFPPRODMARCA(intval($nrrfp));
            $this->deleteRFMAIN(intval($nrrfp));
            $rowsFromTable['ERROS'] = $this->errors;
        }
        return $rowsFromTable;
    }
    public function insertRFPMAIN($row) {
        $query = $this->entityManager->getConnection()->prepare(
        "INSERT INTO RFPMAIN (NRRFPMAIN,
                     COMPRADOR,
                     CDFILIAL,
                     DTVALIDADEINICIAL,
                     DTVALIDADEFINAL,
                     STATUS,
                     DTIMPORTACAO,
                     RESPONSAVEL,
                     DSARQUIVO,
                     CDOPERLOGADO)
             VALUES (SEQ_RFPMAIN_NRRFPMAIN.NEXTVAL,
                     :COMPRADOR,
                     :CDFILIAL,
                     :DTVALIDADEINICIAL,
                     :DTVALIDADEFINAL,
                     :STATUS,
                     :DTIMPORTACAO,
                     :RESPONSAVEL,
                     :DSARQUIVO,
                     :CDOPERLOGADO)"
            );
            $query->execute(
                array(
                    "COMPRADOR" => $row["COMPRADOR"],
                    "CDFILIAL" => $row["CDFILIAL"],
                    "DTVALIDADEINICIAL" => $row["DTVALIDADEINICIAL"],
                    "DTVALIDADEFINAL" => $row["DTVALIDADEFINAL"],
                    "STATUS" => $row['STATUS'],
                    "DTIMPORTACAO" => $row["DTIMPORTACAO"],
                    "RESPONSAVEL" => $row["RESPONSAVEL"],
                    "DSARQUIVO" => $row["DSARQUIVO"],
                    "CDOPERLOGADO" => $row["CDOPERLOGADO"]
                )
            );
    }
    public function insertRFPPRODMARCA($row) {
        $query = $this->entityManager->getConnection()->prepare(
        "INSERT
         INTO RFPPRODMARCA (
            NRRFPPRODMARCA,
            NRRFPMAIN,
            CODPRODUTO,
            CODMARCA1,
            NMMARCA1,
            VRPRECO1,
            CODMARCA2,
            NMMARCA2,
            VRPRECO2,
            CODMARCA3,
            NMMARCA3,
            VRPRECO3,
            CODMARCA4,
            NMMARCA4,
            VRPRECO4,
            CODMARCA5,
            NMMARCA5,
            VRPRECO5) 
        VALUES (
            SEQ_RFPPRODMARCA_NRRFPPRDMARCA.NEXTVAL,
            :NRRFPMAIN,
            :CODPRODUTO,
            :CODMARCA1,
            :NMMARCA1,
            :VRPRECO1,
            :CODMARCA2,
            :NMMARCA2,
            :VRPRECO2,
            :CODMARCA3,
            :NMMARCA3,
            :VRPRECO3,
            :CODMARCA4,
            :NMMARCA4,
            :VRPRECO4,
            :CODMARCA5,
            :NMMARCA5,
            :VRPRECO5)"
            );
            $query->execute(
                array(
                    "NRRFPMAIN" => $row["NRRFPMAIN"],
                    "CODPRODUTO" => $row["CODPRODUTO"],
                    "CODMARCA1" => $row["CODMARCA1"],
                    "NMMARCA" => $row['NMMARCA1'],
                    "VRPRECO1" => $row["VRPRECO1"],
                    "CODMARCA2" => $row["CODMARCA2"],
                    "NMMARCA2" => $row['NMMARCA2'],
                    "VRPRECO2" => $row["VRPRECO2"],
                    "CODMARCA3" => $row["CODMARCA3"],
                    "NMMARCA3" => $row['NMMARCA3'],
                    "VRPRECO3" => $row["VRPRECO3"],
                    "CODMARCA4" => $row["CODMARCA4"],
                    "NMMARCA4" => $row['NMMARCA4'],
                    "VRPRECO4" => $row["VRPRECO4"],
                    "CODMARCA5" => $row["CODMARCA5"],
                    "NMMARCA5" => $row['NMMARCA5'],
                    "VRPRECO5" => $row["VRPRECO5"]
                )
            );
    }
    public function insertRFPREGIAO($row, $row2) {
        $query = $this->entityManager->getConnection()->prepare(
        "INSERT
         INTO RFPREGIAO (
            NRRFPREGIAO,
            CODREGIAO,
            NRRFPMAIN) 
        VALUES (
            SEQ_RFPREGIAO_NRRFPREGIAO.NEXTVAL,
            :CODREGIAO,
            :NRRFPMAIN)"
            );
            $query->execute(
                array(
                    "CODREGIAO" => $row,
                    "NRRFPMAIN" => $row2
                )
            );
    }
    public function insertRFPFORNECEDOR($row, $row2) {
        $query = $this->entityManager->getConnection()->prepare(
        "INSERT
         INTO RFPFORNECEDOR (
            NRRFPFORNECEDOR,
            NRINSJURFRFP,
            NRRFPMAIN) 
        VALUES (
            SEQ_RFPFORNECEDOR_NRRFPFORN.NEXTVAL,
            :NRINSJURFRFP,
            :NRRFPMAIN)"
            );
            $query->execute(
                array(
                    "NRINSJURFRFP" => $row,
                    "NRRFPMAIN" => $row2
                )
            );
    }
    public function searchNRRFPMAIN($row){
        $sql = "
        SELECT
            NRRFPMAIN
        FROM
            RFPMAIN
        WHERE
            RESPONSAVEL = :RESPONSAVEL
            AND DTVALIDADEINICIAL = :DTVALIDADEINICIAL
            AND DTVALIDADEFINAL = :DTVALIDADEFINAL
            AND COMPRADOR = :COMPRADOR
            AND DSARQUIVO = :DSARQUIVO";
        $params = array(
                    "COMPRADOR" => $row["COMPRADOR"],
                    "DTVALIDADEINICIAL" => $row["DTVALIDADEINICIAL"],
                    "DTVALIDADEFINAL" => $row["DTVALIDADEFINAL"],
                    "RESPONSAVEL" => $row["RESPONSAVEL"],
                    "DSARQUIVO" => $row["DSARQUIVO"]
            );
        $answer = $this->entityManager->getConnection()->fetchAll($sql, $params);
        if(!empty($answer)) $answer = $answer[0]['NRRFPMAIN'];
        return $answer;
    }
    public function searchSTATUS($row){
        $sql = "
        SELECT
            STATUS
        FROM
            RFPMAIN
        WHERE
            RESPONSAVEL = :RESPONSAVEL
            AND DTVALIDADEINICIAL = :DTVALIDADEINICIAL
            AND DTVALIDADEFINAL = :DTVALIDADEFINAL
            AND COMPRADOR = :COMPRADOR";
        $params = array(
                    "COMPRADOR" => $row["COMPRADOR"],
                    "DTVALIDADEINICIAL" => $row["DTVALIDADEINICIAL"],
                    "DTVALIDADEFINAL" => $row["DTVALIDADEFINAL"],
                    "RESPONSAVEL" => $row["RESPONSAVEL"]
            );
        $answer = $this->entityManager->getConnection()->fetchAll($sql, $params);
        if(!empty($answer)) $answer = $answer[0]['STATUS'];
        return $answer;
    }
    public function searchSTATUSDelete($row){
        $sql = "
        SELECT
            STATUS
        FROM
            RFPMAIN
        WHERE
            RESPONSAVEL = :RESPONSAVEL
            AND DTVALIDADEINICIAL = :DTVALIDADEINICIAL
            AND DTVALIDADEFINAL = :DTVALIDADEFINAL
            AND CDCOMPRADOR = :CDCOMPRADOR
            AND NRRFPMAIN = :NRRFPMAIN";
        $params = array(
                    "CDCOMPRADOR" => $row["CDCOMPRADOR"],
                    "DTVALIDADEINICIAL" => $row["DTVALIDADEINICIAL"],
                    "DTVALIDADEFINAL" => $row["DTVALIDADEFINAL"],
                    "RESPONSAVEL" => $row["RESPONSAVEL"],
                    "NRRFPMAIN" => $row["NRRFPMAIN"]
            );
        $answer = $this->entityManager->getConnection()->fetchAll($sql, $params);
        if(!empty($answer)) $answer = $answer[0]['STATUS'];
        return $answer;
    }
    public function deleteRFMAIN($params){
        try {
            $query = "DELETE FROM RFPMAIN RF WHERE RF.NRRFPMAIN = :NRRFPMAIN";
            $params = [
                "NRRFPMAIN"    => $params
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao excluir os registros!');
        }
    }
    public function deleteRFPPRODMARCA($params){
        try {
            $query = "DELETE FROM RFPPRODMARCA RFP WHERE RFP.NRRFPMAIN = :NRRFPMAIN";
            $params = [
                "NRRFPMAIN"    => $params
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao excluir os registros!');
        }
    }
    public function deleteRFPREGIAO($params){
        try {
            $query = "DELETE FROM RFPREGIAO RFPR WHERE RFPR.NRRFPMAIN = :NRRFPMAIN";
            $params = [
                "NRRFPMAIN"    => $params
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao excluir os registros!');
        }
    }
    public function deleteRFPFORNECEDOR($params){
        try {
            $query = "DELETE FROM RFPFORNECEDOR RFPF WHERE RFPF.NRRFPMAIN = :NRRFPMAIN";
            $params = [
                "NRRFPMAIN"    => $params
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao excluir os registros!');
        }
    }

}